==> kubernetes-model-core-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/APIServiceListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class APIServiceListFluentImpl<A extends APIServiceListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements APIServiceListFluent<A> {

    private String apiVersion;
    private List<APIServiceBuilder> items =  new ArrayList<APIServiceBuilder>();
    private String kind;
    private ListMetaBuilder metadata;

    public APIServiceListFluentImpl() { 
    }


    public APIServiceListFluentImpl(APIServiceList instance) { 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }


    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,APIService item) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,APIService item) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        APIServiceBuilder builder = new APIServiceBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(APIService... items) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<APIService> items) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(APIService... items) {
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<APIService> items) {
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<APIServiceBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<APIServiceBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          APIServiceBuilder builder = each.next();
          if (predicate.apply(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<APIService> getItems() {
        return build(items);
    }

    public List<APIService> buildItems() {
        return build(items);
    }

    public APIService buildItem(int index) {
        return this.items.get(index).build();
    }

    public APIService buildFirstItem() {
        return this.items.get(0).build();
    }

    public APIService buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public APIService buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServiceBuilder> predicate) {
        for (APIServiceBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServiceBuilder> predicate) {
        for (APIServiceBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<APIService> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<APIServiceBuilder>(); for (APIService item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(APIService... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (APIService item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public APIServiceListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public APIServiceListFluent.ItemsNested<A> addNewItemLike(APIService item) {
        return new ItemsNestedImpl(-1, item);
    }

    public APIServiceListFluent.ItemsNested<A> setNewItemLike(int index,APIService item) {
        return new ItemsNestedImpl(index, item);
    }

    public APIServiceListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public APIServiceListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public APIServiceListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public APIServiceListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<APIServiceBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.apply(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public APIServiceListFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public APIServiceListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item) {
        return new MetadataNestedImpl(item);
    }

    public APIServiceListFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public APIServiceListFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public APIServiceListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        APIServiceListFluentImpl that = (APIServiceListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends APIServiceFluentImpl<APIServiceListFluent.ItemsNested<N>> implements APIServiceListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final APIServiceBuilder builder;
        private final int index;

        ItemsNestedImpl(int index,APIService item) {
            this.index = index;
            this.builder = new APIServiceBuilder(this, item);
        }

        ItemsNestedImpl() {
            this.index = -1;
            this.builder = new APIServiceBuilder(this);
        }

        public N and() {
             return (N) APIServiceListFluentImpl.this.setToItems(index,builder.build());
        }

        public N endItem() {
             return and();
        }
    }


    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<APIServiceListFluent.MetadataNested<N>> implements APIServiceListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ListMetaBuilder builder;

        MetadataNestedImpl(ListMeta item) {
            this.builder = new ListMetaBuilder(this, item);
        }

        MetadataNestedImpl() {
            this.builder = new ListMetaBuilder(this);
        }

        public N and() {
             return (N) APIServiceListFluentImpl.this.withMetadata(builder.build());
        }

        public N endMetadata() {
             return and();
        }
    }


}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/APIServiceListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class APIServiceListFluentImpl<A extends APIServiceListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements APIServiceListFluent<A> {

    private String apiVersion;
    private List<APIServiceBuilder> items =  new ArrayList<APIServiceBuilder>();
    private String kind;
    private ListMetaBuilder metadata;

    public APIServiceListFluentImpl() {
    }

    public APIServiceListFluentImpl(APIServiceList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,APIService item) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,APIService item) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        APIServiceBuilder builder = new APIServiceBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(APIService... items) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<APIService> items) {
        if (this.items == null) {this.items = new ArrayList<APIServiceBuilder>();}
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(APIService... items) {
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<APIService> items) {
        for (APIService item : items) {APIServiceBuilder builder = new APIServiceBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<APIServiceBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<APIServiceBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          APIServiceBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<APIService> getItems() {
        return build(items);
    }

    public List<APIService> buildItems() {
        return build(items);
    }

    public APIService buildItem(int index) {
        return this.items.get(index).build();
    }

    public APIService buildFirstItem() {
        return this.items.get(0).build();
    }

    public APIService buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public APIService buildMatchingItem(Predicate<APIServiceBuilder> predicate) {
        for (APIServiceBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<APIServiceBuilder> predicate) {
        for (APIServiceBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<APIService> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<APIServiceBuilder>(); for (APIService item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(APIService... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (APIService item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> addNewItemLike(APIService item) {
        return new ItemsNestedImpl(-1, item);
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> setNewItemLike(int index,APIService item) {
        return new ItemsNestedImpl(index, item);
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<APIServiceBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item) {
        return new MetadataNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        APIServiceListFluentImpl that = (APIServiceListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends APIServiceFluentImpl<io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<N>> implements io.fabric8.kubernetes.api.model.APIServiceListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final APIServiceBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,APIService item) {
                this.index = index;
                this.builder = new APIServiceBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new APIServiceBuilder(this);
                        
            }

            public N and() {
                return (N) APIServiceListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<N>> implements io.fabric8.kubernetes.api.model.APIServiceListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ListMetaBuilder builder;

            MetadataNestedImpl(ListMeta item) {
                this.builder = new ListMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ListMetaBuilder(this);
                        
            }

            public N and() {
                return (N) APIServiceListFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


}
